//[mahjong-utils](../../index.md)/[mahjongutils.models](index.md)/[Furo](-furo.md)

# Furo

[common]\
fun [Furo](-furo.md)(vararg tiles: [Tile](-tile/index.md), ankan: [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) = false): [Furo](-furo/index.md)

fun [Furo](-furo.md)(tiles: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Tile](-tile/index.md)&gt;, ankan: [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) = false): [Furo](-furo/index.md)

fun [Furo](-furo.md)(text: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html), ankan: [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) = false): [Furo](-furo/index.md)
